<?php
namespace Guestbook\CaGuestbook\Controller;


/***************************************************************
 *
 *  Copyright notice
 *
 *  (c) 2015
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * EntriesController
 */
class EntriesController extends \TYPO3\CMS\Extbase\Mvc\Controller\ActionController {

	/**
	 * entriesRepository
	 *
	 * @var \Guestbook\CaGuestbook\Domain\Repository\EntriesRepository
	 * @inject
	 */
	protected $entriesRepository = NULL;

	/**
	 * action list
	 *
	 * @return void
	 */
	public function listAction() {
        $itemsPerPage = (int)$this->settings["listings"]["maxPerPage"];
        
        
        if($this->request->hasArgument('page')) {
            $page = $this->request->getArgument('page');
        } else {
            $page = 1;
        } 
              
        $entriesCount = $this->entriesRepository->countAll();
        
        if($entriesCount <= $itemsPerPage) {
            $entries = $this->queryGuestbookEntries(0, $itemsPerPage);
        } else {
            
            $queryOffset = $itemsPerPage * ($page - 1);
            $entries = $this->queryGuestbookEntries($queryOffset, $itemsPerPage);
            $pages = ceil($entriesCount / $itemsPerPage);
            
            if ($pages <= 10) {
                $minPagination = 1;
                $maxPagination = $pages;
            }
            //Case II: the calculated pages are more than 10
            if ($pages > 10) {
                $maxPagination = $page + 5;
                if ($maxPagination > $pages) {
                    $maxPagination = $pages;
                }
                $minPagination = $maxPagination -11;
                if($minPagination <1) {
                    $minPagination = 1;
                    $maxPagination = 11;
                }
            }
    
            //PAGENAVIGATION
            for ($i = $minPagination; $i <= $maxPagination; $i++) {
                $pagination['pages'][$i]['text'] = $i;
            }
            //next / prev
            if($page > 1) {
                $pagination['prev'] = $page -1;
            }
            if($page < $pages) {
                $pagination['next'] = $page +1;
            }
            //firstpage / lastPage
            if($minPagination > 1){
                $pagination['first'] = 1;
            }
            if($maxPagination < $pages){
                $pagination['last'] = $pages;
            }
    
            //current page
            $pagination['current'] = $page;
   
	   }
       $this->view->assign('pagination', $pagination);
       $this->view->assign('entriess', $entries);  
    }
    

    public function queryGuestbookEntries($offset, $limit) {
        $query = $this->entriesRepository->createQuery();
        $query->getQuerySettings()->setRespectStoragePage(TRUE);
        
        $query->setOffset($offset);
        $query->setLimit($limit);
        
        $query->setOrderings(
            array(
                'date'    => \TYPO3\CMS\Extbase\Persistence\QueryInterface::ORDER_DESCENDING,
                //'time_end'      => \TYPO3\CMS\Extbase\Persistence\QueryInterface::ORDER_ASCENDING
            )
        );
        $result = $query->execute();
        return $result;
    }
       
	/**
	 * action new
	 *
	 * @param \Guestbook\CaGuestbook\Domain\Model\Entries $newEntries
	 * @ignorevalidation $newEntries
	 * @return void
	 */
	public function newAction(\Guestbook\CaGuestbook\Domain\Model\Entries $newEntries = NULL) {
        $this->view->assign('reCaptcha_clientkey', $this->settings["reCaptcha"]["clientkey"]);
		$this->view->assign('newEntries', $newEntries);
	}

	/**
	 * action create
	 *
	 * @param \Guestbook\CaGuestbook\Domain\Model\Entries $newEntries
	 * @return void
	 */
	public function createAction(\Guestbook\CaGuestbook\Domain\Model\Entries $newEntries) {
        $this->addFlashMessage('The object was created. Please be aware that this action is publicly accessible unless you implement an access check. See <a href="http://wiki.typo3.org/T3Doc/Extension_Builder/Using_the_Extension_Builder#1._Model_the_domain" target="_blank">Wiki</a>', '', \TYPO3\CMS\Core\Messaging\AbstractMessage::ERROR);
        $this->entriesRepository->add($newEntries);
        $this->redirect('list');
	}
    

}